summaryrefslogtreecommitdiffhomepage
path: root/Kernel/Sources/FileManager.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'Kernel/Sources/FileManager.cxx')
-rw-r--r--Kernel/Sources/FileManager.cxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/Kernel/Sources/FileManager.cxx b/Kernel/Sources/FileManager.cxx
index 634e4fd6..96e42dc9 100644
--- a/Kernel/Sources/FileManager.cxx
+++ b/Kernel/Sources/FileManager.cxx
@@ -37,13 +37,13 @@ namespace Kernel
}
/// @brief Mount filesystem.
/// @param mountPtr The filesystem to mount.
/// @return if it succeeded true, otherwise false.
- bool FilesystemManagerInterface::Mount(_Input FilesystemManagerInterface* mountPtr)
+ bool FilesystemManagerInterface::Mount(_Input FilesystemManagerInterface* mount_ptr)
{
- if (kMounted == nullptr)
+ if (mount_ptr != nullptr)
{
- kMounted = mountPtr;
+ kMounted = mount_ptr;
return true;
}
@@ -37,13 +37,13 @@ namespace Kernel
}
/// @brief Mount filesystem.
- /// @param mountPtr The filesystem to mount.
+ /// @param mount_ptr The filesystem to mount.
/// @return if it succeeded true, otherwise false.